description = [
    {
        "description": "Optimize anaerobic digestion process conditions to maximize VFA production or methane yield.",
        "name": "optimize_anaerobic_digestion_process",
        "optional_parameters": [
            {
                "default": "methane_yield",
                "description": "Target output to maximize, either 'vfa_production' or 'methane_yield'",
                "name": "target_output",
                "type": "str",
            },
            {
                "default": "rsm",
                "description": "Method used for optimization, "
                "either 'rsm' (Response Surface "
                "Methodology) or 'genetic' (Genetic "
                "Algorithm)",
                "name": "optimization_method",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Dictionary containing waste "
                "characteristics such as "
                "total_solids, volatile_solids, and "
                "cod",
                "name": "waste_characteristics",
                "type": "dict",
            },
            {
                "default": None,
                "description": "Dictionary containing operational "
                "parameters and their ranges for "
                "hrt, olr, if_ratio, temperature, "
                "and ph",
                "name": "operational_parameters",
                "type": "dict",
            },
        ],
    },
    {
        "description": "Analyzes arsenic speciation in liquid samples using "
        "HPLC-ICP-MS technique. Returns a research log summarizing "
        "analysis steps and results.",
        "name": "analyze_arsenic_speciation_hplc_icpms",
        "optional_parameters": [
            {
                "default": "Unknown Sample",
                "description": "Name of the sample being analyzed",
                "name": "sample_name",
                "type": "str",
            },
            {
                "default": None,
                "description": "Dictionary containing calibration "
                "standards data with known "
                "concentrations for each arsenic "
                "species",
                "name": "calibration_data",
                "type": "dict",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Dictionary containing sample data "
                "with keys as sample IDs and values "
                "as dictionaries with retention "
                "times (in minutes) as keys and "
                "signal intensities as values",
                "name": "sample_data",
                "type": "dict",
            }
        ],
    },
    {
        "description": "Count bacterial colonies from an image of agar plate using computer vision techniques.",
        "name": "count_bacterial_colonies",
        "optional_parameters": [
            {
                "default": 1,
                "description": "Dilution factor of the plated sample",
                "name": "dilution_factor",
                "type": "float",
            },
            {
                "default": 65.0,
                "description": "Area of the agar plate in square centimeters",
                "name": "plate_area_cm2",
                "type": "float",
            },
            {
                "default": "./output",
                "description": "Directory to save output images and results",
                "name": "output_dir",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the image file containing bacterial colonies on agar plate",
                "name": "image_path",
                "type": "str",
            }
        ],
    },
    {
        "description": "Annotate a bacterial genome using Prokka to identify genes, proteins, and functional features.",
        "name": "annotate_bacterial_genome",
        "optional_parameters": [
            {
                "default": "annotation_results",
                "description": "Directory where annotation results will be saved",
                "name": "output_dir",
                "type": "str",
            },
            {
                "default": "",
                "description": "Genus name for the organism",
                "name": "genus",
                "type": "str",
            },
            {
                "default": "",
                "description": "Species name for the organism",
                "name": "species",
                "type": "str",
            },
            {
                "default": "",
                "description": "Strain identifier",
                "name": "strain",
                "type": "str",
            },
            {
                "default": "",
                "description": "Prefix for output files",
                "name": "prefix",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the assembled genome sequence file in FASTA format",
                "name": "genome_file_path",
                "type": "str",
            }
        ],
    },
    {
        "description": "Quantify bacterial concentration (CFU/mL) using serial dilutions and spot plating.",
        "name": "enumerate_bacterial_cfu_by_serial_dilution",
        "optional_parameters": [
            {
                "default": 1.0,
                "description": "Volume of the initial bacterial sample in milliliters",
                "name": "initial_sample_volume_ml",
                "type": "float",
            },
            {
                "default": 100000000.0,
                "description": "Estimated concentration of bacteria in the initial sample (CFU/mL)",
                "name": "estimated_concentration",
                "type": "float",
            },
            {
                "default": 10,
                "description": "Factor by which each dilution reduces the concentration",
                "name": "dilution_factor",
                "type": "int",
            },
            {
                "default": 8,
                "description": "Number of serial dilutions to perform",
                "name": "num_dilutions",
                "type": "int",
            },
            {
                "default": 3,
                "description": "Number of replicate spots to plate for each dilution",
                "name": "spots_per_dilution",
                "type": "int",
            },
            {
                "default": "cfu_enumeration_results.csv",
                "description": "Filename to save the CFU enumeration results",
                "name": "output_file",
                "type": "str",
            },
        ],
        "required_parameters": [],
    },
    {
        "description": "Model bacterial population dynamics over time using ordinary differential equations.",
        "name": "model_bacterial_growth_dynamics",
        "optional_parameters": [
            {
                "default": 24,
                "description": "Total simulation time in hours",
                "name": "simulation_time",
                "type": "float",
            },
            {
                "default": 0.1,
                "description": "Time step for simulation output",
                "name": "time_step",
                "type": "float",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Initial bacterial population size (CFU/ml or cells)",
                "name": "initial_population",
                "type": "float",
            },
            {
                "default": None,
                "description": "Bacterial growth rate (per hour)",
                "name": "growth_rate",
                "type": "float",
            },
            {
                "default": None,
                "description": "Rate at which bacteria are cleared from the system (per hour)",
                "name": "clearance_rate",
                "type": "float",
            },
            {
                "default": None,
                "description": "Maximum carrying capacity of the environment (CFU/ml or cells)",
                "name": "niche_size",
                "type": "float",
            },
        ],
    },
    {
        "description": "Quantifies biofilm biomass using crystal violet staining "
        "assay data and returns a detailed research log.",
        "name": "quantify_biofilm_biomass_crystal_violet",
        "optional_parameters": [
            {
                "default": None,
                "description": "Names of the biofilm samples corresponding to od_values",
                "name": "sample_names",
                "type": "List[str]",
            },
            {
                "default": 0,
                "description": "Index of the negative control sample in od_values",
                "name": "control_index",
                "type": "int",
            },
            {
                "default": None,
                "description": "Path to save the results as CSV file",
                "name": "save_path",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Optical density measurements from "
                "crystal violet staining "
                "representing absorbance readings "
                "for samples",
                "name": "od_values",
                "type": "List[float] or numpy.ndarray",
            }
        ],
    },
    {
        "description": "Perform automated cell segmentation and quantify "
        "morphological metrics from fluorescence microscopy images.",
        "name": "segment_and_analyze_microbial_cells",
        "optional_parameters": [
            {
                "default": "./output",
                "description": "Directory to save output files",
                "name": "output_dir",
                "type": "str",
            },
            {
                "default": 50,
                "description": "Minimum cell size in pixels to filter noise",
                "name": "min_cell_size",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the fluorescence microscopy image file",
                "name": "image_path",
                "type": "str",
            }
        ],
    },
    {
        "description": "Perform cell segmentation on fluorescence microscopy images "
        "using deep learning with pre-trained models from the "
        "Cellpose/Omnipose library.",
        "name": "segment_cells_with_deep_learning",
        "optional_parameters": [
            {
                "default": "bact_fluor_omni",
                "description": "Name of the pre-trained model to "
                "use (Options include: "
                "'bact_fluor_omni', 'cyto', "
                "'nuclei', etc.)",
                "name": "model_type",
                "type": "str",
            },
            {
                "default": None,
                "description": "Expected diameter of cells in pixels. If None, diameter is automatically estimated",
                "name": "diameter",
                "type": "float",
            },
            {
                "default": "segmentation_results",
                "description": "Directory to save segmentation results",
                "name": "save_dir",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the fluorescence microscopy image file",
                "name": "image_path",
                "type": "str",
            }
        ],
    },
    {
        "description": "Simulate microbial community dynamics using the Generalized Lotka-Volterra (gLV) model.",
        "name": "simulate_generalized_lotka_volterra_dynamics",
        "optional_parameters": [
            {
                "default": "glv_simulation_results.csv",
                "description": "Filename to save the simulation results",
                "name": "output_file",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Initial abundances of each microbial species (1D array)",
                "name": "initial_abundances",
                "type": "numpy.ndarray",
            },
            {
                "default": None,
                "description": "Intrinsic growth rates for each microbial species (1D array)",
                "name": "growth_rates",
                "type": "numpy.ndarray",
            },
            {
                "default": None,
                "description": "Matrix of interaction coefficients "
                "where A[i,j] represents the effect "
                "of species j on species i (2D "
                "array)",
                "name": "interaction_matrix",
                "type": "numpy.ndarray",
            },
            {
                "default": None,
                "description": "Time points at which to evaluate the model",
                "name": "time_points",
                "type": "numpy.ndarray",
            },
        ],
    },
    {
        "description": "Predict the secondary structure of an RNA molecule using ViennaRNA.",
        "name": "predict_rna_secondary_structure",
        "optional_parameters": [
            {
                "default": "rna_structure",
                "description": "Prefix for output files",
                "name": "output_prefix",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "The RNA sequence (consisting of A, U, G, C nucleotides)",
                "name": "rna_sequence",
                "type": "str",
            }
        ],
    },
    {
        "description": "Performs stochastic simulation of microbial population dynamics using the Gillespie algorithm.",
        "name": "simulate_microbial_population_dynamics",
        "optional_parameters": [
            {
                "default": 100,
                "description": "Maximum simulation time",
                "name": "max_time",
                "type": "float",
            },
            {
                "default": 100,
                "description": "Number of stochastic simulations to run",
                "name": "num_simulations",
                "type": "int",
            },
            {
                "default": 100,
                "description": "Number of time points to record for trajectories",
                "name": "time_points",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Initial population sizes for each microbial species",
                "name": "initial_populations",
                "type": "List[int]",
            },
            {
                "default": None,
                "description": "Per capita growth rates for each species",
                "name": "growth_rates",
                "type": "List[float]",
            },
            {
                "default": None,
                "description": "Per capita death/clearance rates for each species",
                "name": "clearance_rates",
                "type": "List[float]",
            },
            {
                "default": None,
                "description": "Maximum sustainable population for each species",
                "name": "carrying_capacities",
                "type": "List[float]",
            },
        ],
    },
]



description = [
    {
        "description": "Run DiffDock molecular docking using a protein PDB file and "
        "a SMILES string for the ligand, executing the process in a "
        "Docker container.",
        "name": "run_diffdock_with_smiles",
        "optional_parameters": [
            {
                "default": 0,
                "description": "GPU device ID to use for computation",
                "name": "gpu_device",
                "type": "int",
            },
            {
                "default": True,
                "description": "Whether to use GPU acceleration for docking",
                "name": "use_gpu",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the protein PDB file for docking",
                "name": "pdb_path",
                "type": "str",
            },
            {
                "default": None,
                "description": "SMILES string representation of the ligand molecule",
                "name": "smiles_string",
                "type": "str",
            },
            {
                "default": None,
                "description": "Local directory path where docking results will be saved",
                "name": "local_output_dir",
                "type": "str",
            },
        ],
    },
    {
        "description": "Performs molecular docking using AutoDock Vina to predict "
        "binding affinities between small molecules and a receptor "
        "protein.",
        "name": "docking_autodock_vina",
        "optional_parameters": [
            {
                "default": 1,
                "description": "Number of CPU cores to use for docking",
                "name": "ncpu",
                "type": "int",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "List of SMILES strings representing small molecules to dock",
                "name": "smiles_list",
                "type": "List[str]",
            },
            {
                "default": None,
                "description": "Path to the receptor protein structure PDB file",
                "name": "receptor_pdb_file",
                "type": "str",
            },
            {
                "default": None,
                "description": "3D coordinates [x, y, z] of the docking box center",
                "name": "box_center",
                "type": "List[float]",
            },
            {
                "default": None,
                "description": "Dimensions [x, y, z] of the docking box",
                "name": "box_size",
                "type": "List[float]",
            },
        ],
    },
    {
        "description": "Runs AutoSite on a PDB file to identify potential binding "
        "sites and returns a research log with the results.",
        "name": "run_autosite",
        "optional_parameters": [
            {
                "default": 1.0,
                "description": "Grid spacing parameter for AutoSite calculation",
                "name": "spacing",
                "type": "float",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the input PDB file",
                "name": "pdb_file",
                "type": "str",
            },
            {
                "default": None,
                "description": "Directory where AutoSite results will be saved",
                "name": "output_dir",
                "type": "str",
            },
        ],
    },
    {
        "description": "Computes TxGNN model predictions for drug repurposing and "
        "returns the top predicted drugs with their scores for a "
        "given disease.",
        "name": "retrieve_topk_repurposing_drugs_from_disease_txgnn",
        "optional_parameters": [
            {
                "default": 5,
                "description": "The number of top drug predictions to return",
                "name": "k",
                "type": "int",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "The name of the disease for which to retrieve drug predictions",
                "name": "disease_name",
                "type": "str",
            },
            {
                "default": None,
                "description": "Path to the data lake",
                "name": "data_lake_path",
                "type": "str",
            },
        ],
    },
    {
        "description": "Predicts ADMET (Absorption, Distribution, Metabolism, "
        "Excretion, Toxicity) properties for a list of compounds "
        "using pretrained models.",
        "name": "predict_admet_properties",
        "optional_parameters": [
            {
                "default": "MPNN",
                "description": "Type of model to use for ADMET prediction (options: 'MPNN', 'CNN', 'Morgan')",
                "name": "ADMET_model_type",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "List of SMILES strings representing chemical compounds to analyze",
                "name": "smiles_list",
                "type": "List[str]",
            }
        ],
    },
    {
        "description": "Predicts binding affinity between small molecules and a "
        "protein sequence using pre-trained deep learning models.",
        "name": "predict_binding_affinity_protein_1d_sequence",
        "optional_parameters": [
            {
                "default": "MPNN-CNN",
                "description": "Deep learning model architecture to "
                "use for binding affinity prediction "
                "(options: CNN-CNN, MPNN-CNN, "
                "Morgan-CNN, Morgan-AAC, "
                "Daylight-AAC)",
                "name": "affinity_model_type",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "List of SMILES strings representing chemical compounds",
                "name": "smiles_list",
                "type": "List[str]",
            },
            {
                "default": None,
                "description": "Protein sequence in amino acid format",
                "name": "amino_acid_sequence",
                "type": "str",
            },
        ],
    },
    {
        "description": "Analyzes the stability of pharmaceutical formulations under accelerated storage conditions.",
        "name": "analyze_accelerated_stability_of_pharmaceutical_formulations",
        "optional_parameters": [],
        "required_parameters": [
            {
                "default": None,
                "description": "List of formulation dictionaries "
                "containing name, active ingredient, "
                "concentration, and excipients",
                "name": "formulations",
                "type": "List[dict]",
            },
            {
                "default": None,
                "description": "List of storage condition "
                "dictionaries containing "
                "temperature, humidity (optional), "
                "and description",
                "name": "storage_conditions",
                "type": "List[dict]",
            },
            {
                "default": None,
                "description": "List of time points in days to evaluate stability",
                "name": "time_points",
                "type": "List[int]",
            },
        ],
    },
    {
        "description": "Generates a detailed protocol for performing a 3D "
        "chondrogenic aggregate culture assay to evaluate compounds' "
        "effects on chondrogenesis.",
        "name": "run_3d_chondrogenic_aggregate_assay",
        "optional_parameters": [
            {
                "default": 21,
                "description": "Total duration of the culture period in days",
                "name": "culture_duration_days",
                "type": "int",
            },
            {
                "default": 7,
                "description": "Interval in days between measurements",
                "name": "measurement_intervals",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Dictionary with cell information "
                "including 'source', "
                "'passage_number', and "
                "'cell_density'",
                "name": "chondrocyte_cells",
                "type": "dict",
            },
            {
                "default": None,
                "description": "List of compounds to test, each with 'name', 'concentration', and 'vehicle' keys",
                "name": "test_compounds",
                "type": "list of dict",
            },
        ],
    },
    {
        "description": "Grade and monitor adverse events in animal studies using the VCOG-CTCAE standard.",
        "name": "grade_adverse_events_using_vcog_ctcae",
        "optional_parameters": [],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to a CSV file containing "
                "clinical evaluation data with "
                "columns: subject_id, time_point, "
                "symptom, severity, measurement "
                "(optional)",
                "name": "clinical_data_file",
                "type": "str",
            }
        ],
    },
    {
        "description": "Analyze biodistribution and pharmacokinetic profile of radiolabeled antibodies.",
        "name": "analyze_radiolabeled_antibody_biodistribution",
        "optional_parameters": [],
        "required_parameters": [
            {
                "default": None,
                "description": "Time points (hours) at which measurements were taken",
                "name": "time_points",
                "type": "List[float] or numpy.ndarray",
            },
            {
                "default": None,
                "description": "Dictionary where keys are tissue "
                "names and values are lists/arrays "
                "of %IA/g measurements corresponding "
                "to time_points. Must include "
                "'tumor' as one of the keys",
                "name": "tissue_data",
                "type": "dict",
            },
        ],
    },
    {
        "description": "Estimate radiation absorbed doses to tumor and normal organs "
        "for alpha-particle radiotherapeutics using the Medical "
        "Internal Radiation Dose (MIRD) schema.",
        "name": "estimate_alpha_particle_radiotherapy_dosimetry",
        "optional_parameters": [
            {
                "default": "dosimetry_results.csv",
                "description": "Filename to save the dosimetry results",
                "name": "output_file",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Dictionary containing organ/tissue "
                "names as keys and a list of "
                "time-activity measurements as "
                "values. Each measurement should be "
                "a tuple of (time_hours, "
                "percent_injected_activity). Must "
                "include entries for all relevant "
                "organs including 'tumor'.",
                "name": "biodistribution_data",
                "type": "dict",
            },
            {
                "default": None,
                "description": "Dictionary containing radiation "
                "parameters for the alpha-emitting "
                "radionuclide including "
                "'radionuclide', 'half_life_hours', "
                "'energy_per_decay_MeV', "
                "'radiation_weighting_factor', and "
                "'S_factors'.",
                "name": "radiation_parameters",
                "type": "dict",
            },
        ],
    },
    {
        "description": "Perform a Methylome-wide Association Study (MWAS) to "
        "identify CpG sites significantly associated with CYP2C19 "
        "metabolizer status.",
        "name": "perform_mwas_cyp2c19_metabolizer_status",
        "optional_parameters": [
            {
                "default": None,
                "description": "Path to CSV or TSV file containing "
                "covariates to adjust for in the "
                "regression model (e.g., age, sex, "
                "smoking status).",
                "name": "covariates_path",
                "type": "str",
            },
            {
                "default": 0.05,
                "description": "P-value threshold for significance after multiple testing correction.",
                "name": "pvalue_threshold",
                "type": "float",
            },
            {
                "default": "significant_cpg_sites.csv",
                "description": "Filename to save significant CpG sites.",
                "name": "output_file",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to CSV or TSV file containing "
                "DNA methylation beta values. Rows "
                "should be samples, columns should "
                "be CpG sites.",
                "name": "methylation_data_path",
                "type": "str",
            },
            {
                "default": None,
                "description": "Path to CSV or TSV file containing "
                "CYP2C19 metabolizer status for each "
                "sample. Should have a sample ID "
                "column and a status column.",
                "name": "metabolizer_status_path",
                "type": "str",
            },
        ],
    },
    {
        "description": "Calculate key physicochemical properties of a drug candidate molecule.",
        "name": "calculate_physicochemical_properties",
        "optional_parameters": [],
        "required_parameters": [
            {
                "default": None,
                "description": "The molecular structure in SMILES format",
                "name": "smiles_string",
                "type": "str",
            }
        ],
    },
    {
        "description": "Analyze tumor growth inhibition in xenograft models across different treatment groups.",
        "name": "analyze_xenograft_tumor_growth_inhibition",
        "optional_parameters": [
            {
                "default": "./results",
                "description": "Directory to save output files",
                "name": "output_dir",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to CSV or TSV file containing tumor volume measurements",
                "name": "data_path",
                "type": "str",
            },
            {
                "default": None,
                "description": "Name of the column containing time points",
                "name": "time_column",
                "type": "str",
            },
            {
                "default": None,
                "description": "Name of the column containing tumor volume measurements",
                "name": "volume_column",
                "type": "str",
            },
            {
                "default": None,
                "description": "Name of the column containing treatment group labels",
                "name": "group_column",
                "type": "str",
            },
            {
                "default": None,
                "description": "Name of the column containing subject/mouse identifiers",
                "name": "subject_column",
                "type": "str",
            },
        ],
    },
    {
        "description": "Performs densitometric analysis of Western blot images to "
        "quantify relative protein expression.",
        "name": "analyze_western_blot",
        "optional_parameters": [
            {
                "default": "./results",
                "description": "Directory to save output files",
                "name": "output_dir",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the Western blot image file",
                "name": "blot_image_path",
                "type": "str",
            },
            {
                "default": None,
                "description": "List of dictionaries containing "
                "information about target protein "
                "bands, each with 'name' and 'roi' "
                "(region of interest as [x, y, "
                "width, height])",
                "name": "target_bands",
                "type": "list of dict",
            },
            {
                "default": None,
                "description": "Dictionary with 'name' and 'roi' "
                "for the loading control protein "
                "(e.g., β-actin, GAPDH)",
                "name": "loading_control_band",
                "type": "dict",
            },
            {
                "default": None,
                "description": "Dictionary containing information "
                "about antibodies used with "
                "'primary' and 'secondary' keys",
                "name": "antibody_info",
                "type": "dict",
            },
        ],
    },
    {
        "description": "Query drug-drug interactions from DDInter database to identify potential interactions, mechanisms, and severity levels between specified drugs.",
        "name": "query_drug_interactions",
        "required_parameters": [
            {
                "default": None,
                "description": "List of drug names to query for interactions",
                "name": "drug_names",
                "type": "List[str]",
            }
        ],
        "optional_parameters": [
            {
                "default": None,
                "description": "Filter results by specific interaction types",
                "name": "interaction_types",
                "type": "List[str]",
            },
            {
                "default": None,
                "description": "Filter results by severity levels (Major, Moderate, Minor)",
                "name": "severity_levels",
                "type": "List[str]",
            },
            {
                "default": None,
                "description": "Path to data lake directory containing DDInter data",
                "name": "data_lake_path",
                "type": "str",
            },
        ],
    },
    {
        "description": "Analyze safety of a drug combination for potential interactions using DDInter database with comprehensive risk assessment and clinical recommendations.",
        "name": "check_drug_combination_safety",
        "required_parameters": [
            {
                "default": None,
                "description": "List of drugs to analyze for combination safety",
                "name": "drug_list",
                "type": "List[str]",
            }
        ],
        "optional_parameters": [
            {
                "default": True,
                "description": "Include interaction mechanism descriptions in results",
                "name": "include_mechanisms",
                "type": "bool",
            },
            {
                "default": True,
                "description": "Include management recommendations in results",
                "name": "include_management",
                "type": "bool",
            },
            {
                "default": None,
                "description": "Path to data lake directory containing DDInter data",
                "name": "data_lake_path",
                "type": "str",
            },
        ],
    },
    {
        "description": "Analyze interaction mechanisms between two specific drugs providing detailed mechanistic insights and clinical significance assessment.",
        "name": "analyze_interaction_mechanisms",
        "required_parameters": [
            {
                "default": None,
                "description": "Pair of drug names to analyze (drug1, drug2)",
                "name": "drug_pair",
                "type": "Tuple[str, str]",
            }
        ],
        "optional_parameters": [
            {
                "default": True,
                "description": "Include detailed mechanistic information in analysis",
                "name": "detailed_analysis",
                "type": "bool",
            },
            {
                "default": None,
                "description": "Path to data lake directory containing DDInter data",
                "name": "data_lake_path",
                "type": "str",
            },
        ],
    },
    {
        "description": "Find alternative drugs that don't interact with contraindicated drugs using DDInter database for safer therapeutic substitutions.",
        "name": "find_alternative_drugs_ddinter",
        "required_parameters": [
            {
                "default": None,
                "description": "Drug to find alternatives for",
                "name": "target_drug",
                "type": "str",
            },
            {
                "default": None,
                "description": "List of drugs to avoid interactions with",
                "name": "contraindicated_drugs",
                "type": "List[str]",
            },
        ],
        "optional_parameters": [
            {
                "default": None,
                "description": "Limit search to specific therapeutic class",
                "name": "therapeutic_class",
                "type": "str",
            },
            {
                "default": None,
                "description": "Path to data lake directory containing DDInter data",
                "name": "data_lake_path",
                "type": "str",
            },
        ],
    },
    {
        "description": "Query FDA adverse event reports for specific drugs from the OpenFDA database to identify potential safety signals, reaction patterns, and regulatory intelligence.",
        "name": "query_fda_adverse_events",
        "required_parameters": [
            {
                "default": None,
                "description": "Name of the drug to query for adverse events",
                "name": "drug_name",
                "type": "str",
            },
        ],
        "optional_parameters": [
            {
                "default": None,
                "description": "Optional date range as (start_date, end_date) in YYYY-MM-DD format",
                "name": "date_range",
                "type": "Tuple[str, str]",
            },
            {
                "default": None,
                "description": "Optional filter by severity levels ['serious', 'non_serious']",
                "name": "severity_filter",
                "type": "List[str]",
            },
            {
                "default": None,
                "description": "Optional filter by outcomes ['life_threatening', 'hospitalization', 'death']",
                "name": "outcome_filter",
                "type": "List[str]",
            },
            {
                "default": 100,
                "description": "Maximum number of results to return",
                "name": "limit",
                "type": "int",
            },
        ],
    },
    {
        "description": "Retrieve FDA drug label information including indications, contraindications, warnings, and dosage information from the OpenFDA database.",
        "name": "get_fda_drug_label_info",
        "required_parameters": [
            {
                "default": None,
                "description": "Name of the drug to query for label information",
                "name": "drug_name",
                "type": "str",
            },
        ],
        "optional_parameters": [
            {
                "default": None,
                "description": "Optional list of specific sections to retrieve ['indications_and_usage', 'contraindications', 'warnings', 'dosage_and_administration']",
                "name": "sections",
                "type": "List[str]",
            },
        ],
    },
    {
        "description": "Check for FDA drug recalls and enforcement actions from the OpenFDA database to identify safety concerns and regulatory actions.",
        "name": "check_fda_drug_recalls",
        "required_parameters": [
            {
                "default": None,
                "description": "Name of the drug to check for recalls",
                "name": "drug_name",
                "type": "str",
            },
        ],
        "optional_parameters": [
            {
                "default": None,
                "description": "Optional filter by recall class ['Class I', 'Class II', 'Class III']",
                "name": "classification",
                "type": "List[str]",
            },
            {
                "default": None,
                "description": "Optional date range for recalls as (start_date, end_date)",
                "name": "date_range",
                "type": "Tuple[str, str]",
            },
        ],
    },
    {
        "description": "Analyze safety signals across multiple drugs using OpenFDA adverse event data to identify patterns and comparative risk profiles.",
        "name": "analyze_fda_safety_signals",
        "required_parameters": [
            {
                "default": None,
                "description": "List of drug names to analyze for safety signals",
                "name": "drug_list",
                "type": "List[str]",
            },
        ],
        "optional_parameters": [
            {
                "default": None,
                "description": "Optional comparison time period as (start_date, end_date)",
                "name": "comparison_period",
                "type": "Tuple[str, str]",
            },
            {
                "default": 2.0,
                "description": "Threshold for signal detection",
                "name": "signal_threshold",
                "type": "float",
            },
        ],
    },
]



description = [
    {
        "description": "Quantify the percentage of cells in each cell cycle phase "
        "using Calcofluor white stained microscopy images.",
        "name": "quantify_cell_cycle_phases_from_microscopy",
        "optional_parameters": [
            {
                "default": "./results",
                "description": "Directory to save results",
                "name": "output_dir",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "List of file paths to microscopy images of cells stained with Calcofluor white",
                "name": "image_paths",
                "type": "List[str]",
            }
        ],
    },
    {
        "description": "Quantify cell motility features from time-lapse microscopy "
        "images and cluster cells based on motility patterns.",
        "name": "quantify_and_cluster_cell_motility",
        "optional_parameters": [
            {
                "default": "./results",
                "description": "Directory to save output files",
                "name": "output_dir",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Number of motility pattern clusters to identify",
                "name": "num_clusters",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to directory containing time-lapse microscopy images in sequential order",
                "name": "image_sequence_path",
                "type": "str",
            }
        ],
    },
    {
        "description": "Performs Fluorescence-Activated Cell Sorting (FACS) to "
        "enrich cell populations based on fluorescence "
        "characteristics.",
        "name": "perform_facs_cell_sorting",
        "optional_parameters": [
            {
                "default": None,
                "description": "Minimum threshold for the "
                "fluorescence parameter. Cells below "
                "this value will be excluded",
                "name": "threshold_min",
                "type": "float",
            },
            {
                "default": None,
                "description": "Maximum threshold for the "
                "fluorescence parameter. Cells above "
                "this value will be excluded",
                "name": "threshold_max",
                "type": "float",
            },
            {
                "default": "sorted_cells.csv",
                "description": "Filename to save the sorted cell population data",
                "name": "output_file",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the FCS file containing flow cytometry data",
                "name": "cell_suspension_data",
                "type": "str",
            },
            {
                "default": None,
                "description": "The fluorescence parameter to use for sorting (e.g., 'GFP', 'FITC', 'PE')",
                "name": "fluorescence_parameter",
                "type": "str",
            },
        ],
    },
    {
        "description": "Analyze flow cytometry data to identify and quantify "
        "specific cell populations based on surface markers.",
        "name": "analyze_flow_cytometry_immunophenotyping",
        "optional_parameters": [
            {
                "default": None,
                "description": "Spillover/compensation matrix to correct for fluorescence overlap",
                "name": "compensation_matrix",
                "type": "numpy.ndarray",
            },
            {
                "default": "./results",
                "description": "Directory to save the results",
                "name": "output_dir",
                "type": "str",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the FCS file containing flow cytometry data",
                "name": "fcs_file_path",
                "type": "str",
            },
            {
                "default": None,
                "description": "Dictionary defining the gating "
                "strategy. Each key is a population "
                "name, and each value is a list of "
                "tuples (marker, operator, "
                "threshold)",
                "name": "gating_strategy",
                "type": "dict",
            },
        ],
    },
    {
        "description": "Quantifies metrics of mitochondrial morphology and membrane "
        "potential from fluorescence microscopy images.",
        "name": "analyze_mitochondrial_morphology_and_potential",
        "optional_parameters": [
            {
                "default": "./output",
                "description": "Directory to save output files",
                "name": "output_dir",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Path to the fluorescence microscopy "
                "image showing mitochondrial "
                "morphology (e.g., MTS-GFP)",
                "name": "morphology_image_path",
                "type": "str",
            },
            {
                "default": None,
                "description": "Path to the fluorescence microscopy "
                "image showing mitochondrial "
                "membrane potential (e.g., TMRE "
                "staining)",
                "name": "potential_image_path",
                "type": "str",
            },
        ],
    },
]



description = [
    {
        "description": "Query the UniProt REST API using either natural language or a direct endpoint.",
        "name": "query_uniprot",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full or partial UniProt API "
                "endpoint URL to query directly "
                "(e.g., "
                '"https://rest.uniprot.org/uniprotkb/P01308")',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 5,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": 'Natural language query about proteins (e.g., "Find information about human insulin")',
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the AlphaFold Database API for protein structure predictions.",
        "name": "query_alphafold",
        "optional_parameters": [
            {
                "default": "prediction",
                "description": 'Specific AlphaFold API endpoint to query: "prediction", "summary", or "annotations"',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": 'Specific residue range in format "start-end" (e.g., "1-100")',
                "name": "residue_range",
                "type": "str",
            },
            {
                "default": False,
                "description": "Whether to download structure files",
                "name": "download",
                "type": "bool",
            },
            {
                "default": None,
                "description": "Directory to save downloaded files",
                "name": "output_dir",
                "type": "str",
            },
            {
                "default": "pdb",
                "description": 'Format of the structure file to download - "pdb" or "cif"',
                "name": "file_format",
                "type": "str",
            },
            {
                "default": "v4",
                "description": 'AlphaFold model version - "v4" (latest) or "v3", "v2", "v1"',
                "name": "model_version",
                "type": "str",
            },
            {
                "default": 1,
                "description": "Model number (1-5, with 1 being the highest confidence model)",
                "name": "model_number",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": 'UniProt accession ID (e.g., "P12345")',
                "name": "uniprot_id",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the InterPro REST API using natural language or a direct endpoint.",
        "name": "query_interpro",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct endpoint path or full URL (e.g., '/entry/interpro/IPR023411')",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return per page",
                "name": "max_results",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about protein domains or families",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the RCSB PDB database using natural language or a direct structured query.",
        "name": "query_pdb",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct structured query in RCSB Search API format (overrides prompt)",
                "name": "query",
                "type": "dict",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about protein structures",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Retrieve detailed data and/or download files for PDB identifiers.",
        "name": "query_pdb_identifiers",
        "optional_parameters": [
            {
                "default": "entry",
                "description": "Type of results: 'entry', 'assembly', 'polymer_entity', etc.",
                "name": "return_type",
                "type": "str",
            },
            {
                "default": False,
                "description": "Whether to download PDB structure files",
                "name": "download",
                "type": "bool",
            },
            {
                "default": None,
                "description": "List of specific attributes to retrieve",
                "name": "attributes",
                "type": "List[str]",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "List of PDB identifiers to query",
                "name": "identifiers",
                "type": "List[str]",
            }
        ],
    },
    {
        "description": "Take a natural language prompt and convert it to a structured KEGG API query.",
        "name": "query_kegg",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct KEGG API endpoint to query",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will look for ANTHROPIC_API_KEY environment variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed API response information",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about KEGG "
                'data (e.g., "Find human pathways '
                'related to glycolysis")',
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the STRING protein interaction database using natural language or direct endpoint.",
        "name": "query_stringdb",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full URL to query directly (overrides prompt)",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": False,
                "description": "Whether to download image results (for image endpoints)",
                "name": "download_image",
                "type": "bool",
            },
            {
                "default": None,
                "description": "Directory to save downloaded files",
                "name": "output_dir",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed response information",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about protein interactions",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the IUCN Red List API using natural language or a direct endpoint.",
        "name": "query_iucn",
        "optional_parameters": [
            {
                "default": None,
                "description": "Natural language query about species conservation status",
                "name": "prompt",
                "type": "str",
            },
            {
                "default": None,
                "description": 'API endpoint name (e.g., "species/id/12392") or full URL',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed query information or just formatted results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": "",
                "description": "IUCN API token - required for all queries",
                "name": "token",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the Paleobiology Database (PBDB) API using natural language or a direct endpoint.",
        "name": "query_paleobiology",
        "optional_parameters": [
            {
                "default": None,
                "description": "API endpoint name or full URL",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed query information",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about fossil records",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the JASPAR REST API using natural language or a direct "
        "endpoint to retrieve transcription factor binding profiles.",
        "name": "query_jaspar",
        "optional_parameters": [
            {
                "default": None,
                "description": "API endpoint path (e.g., '/matrix/MA0002.2/') or full URL",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed query information",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about transcription factor binding profiles",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the World Register of Marine Species (WoRMS) REST API "
        "using natural language or a direct endpoint.",
        "name": "query_worms",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full URL or endpoint specification",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return full API response details",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about marine species",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the cBioPortal REST API using natural language or a "
        "direct endpoint to access cancer genomics data.",
        "name": "query_cbioportal",
        "optional_parameters": [
            {
                "default": None,
                "description": "API endpoint path (e.g., '/studies/brca_tcga/patients') or full URL",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed API response information",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about cancer genomics data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Take a natural language prompt and convert it to a structured ClinVar query.",
        "name": "query_clinvar",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct search term to use with the ClinVar API",
                "name": "search_term",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will look for ANTHROPIC_API_KEY environment variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": 'Natural language query about genetic variants (e.g., "Find pathogenic BRCA1 variants")',
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the NCBI Gene Expression Omnibus (GEO) using natural language or a direct search term.",
        "name": "query_geo",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct search term in GEO syntax",
                "name": "search_term",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
            {
                "default": None,
                "description": "Whether to return verbose results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about RNA-seq, microarray, or other expression data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the NCBI dbSNP database using natural language or a direct search term.",
        "name": "query_dbsnp",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct search term in dbSNP syntax",
                "name": "search_term",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
            {
                "default": False,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about genetic variants/SNPs",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the UCSC Genome Browser API using natural language or a direct endpoint.",
        "name": "query_ucsc",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full URL or endpoint specification with parameters",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about genomic data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the Ensembl REST API using natural language or a direct endpoint.",
        "name": "query_ensembl",
        "optional_parameters": [
            {
                "default": None,
                "description": 'Direct API endpoint to query (e.g., "lookup/symbol/human/BRCA2") or full URL',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about genomic data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the OpenTargets Genetics API using natural language or a direct GraphQL query.",
        "name": "query_opentarget_genetics",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct GraphQL query string",
                "name": "query",
                "type": "str",
            },
            {
                "default": None,
                "description": "Variables for the GraphQL query",
                "name": "variables",
                "type": "dict",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed API response information",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about genetic targets and variants",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the OpenTargets Platform API using natural language or a direct GraphQL query.",
        "name": "query_opentarget",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct GraphQL query string",
                "name": "query",
                "type": "str",
            },
            {
                "default": None,
                "description": "Variables for the GraphQL query",
                "name": "variables",
                "type": "dict",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": False,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about drug targets, diseases, and mechanisms",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the GWAS Catalog API using natural language or a direct endpoint.",
        "name": "query_gwas_catalog",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full API endpoint to query (e.g., "
                '"https://www.ebi.ac.uk/gwas/rest/api/studies?diseaseTraitId=EFO_0001360")',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about GWAS data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the Monarch Initiative API using natural language or a direct endpoint.",
        "name": "query_monarch",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct API endpoint to query",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 2,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
            {
                "default": False,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about genetic variants",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query gnomAD for variants in a gene using natural language or direct gene symbol.",
        "name": "query_gnomad",
        "optional_parameters": [
            {
                "default": None,
                "description": 'Gene symbol (e.g., "BRCA1")',
                "name": "gene_symbol",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed query results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about genetic variants",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Identifies a DNA sequence using NCBI BLAST with improved "
        "error handling, timeout management, and debugging",
        "name": "blast_sequence",
        "optional_parameters": [],
        "required_parameters": [
            {
                "default": None,
                "description": "The sequence to identify. If DNA, "
                "use database: core_nt, program: "
                "blastn; if protein, use database: "
                "nr, program: blastp",
                "name": "sequence",
                "type": "str",
            },
            {
                "default": None,
                "description": "The BLAST database to search against",
                "name": "database",
                "type": "str",
            },
            {
                "default": None,
                "description": "The BLAST program to use",
                "name": "program",
                "type": "str",
            },
        ],
    },
    {
        "description": "Query the Reactome database using natural language or a direct endpoint.",
        "name": "query_reactome",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct API endpoint or full URL",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": False,
                "description": "Whether to download pathway diagrams",
                "name": "download",
                "type": "bool",
            },
            {
                "default": None,
                "description": "Directory to save downloaded files",
                "name": "output_dir",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about biological pathways",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the RegulomeDB database using natural language or "
        "direct variant/coordinate specification.",
        "name": "query_regulomedb",
        "optional_parameters": [
            {
                "default": None,
                "description": "Direct API endpoint to query",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": False,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about regulatory elements",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the PRIDE (PRoteomics IDEntifications) database using "
        "natural language or a direct endpoint.",
        "name": "query_pride",
        "optional_parameters": [
            {
                "default": None,
                "description": "The full endpoint to query (e.g., "
                '"https://www.ebi.ac.uk/pride/ws/archive/v2/projects?keyword=breast%20cancer")',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": 3,
                "description": "Maximum number of results to return",
                "name": "max_results",
                "type": "int",
            },
            {
                "default": None,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about proteomics data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the Guide to PHARMACOLOGY database (GtoPdb) using natural language or a direct endpoint.",
        "name": "query_gtopdb",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full API endpoint to query (e.g., "
                '"https://www.guidetopharmacology.org/services/targets?type=GPCR&name=beta-2")',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about drug targets, ligands, and interactions",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Given genomic coordinates, retrieves information of "
        "intersecting candidate cis-regulatory elements (cCREs).",
        "name": "region_to_ccre_screen",
        "optional_parameters": [
            {
                "default": "GRCh38",
                "description": "Assembly of the genome, formatted like 'GRCh38'",
                "name": "assembly",
                "type": "str",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Chromosome of the genomic region, formatted like 'chr12'",
                "name": "coord_chrom",
                "type": "str",
            },
            {
                "default": None,
                "description": "Starting chromosome coordinate",
                "name": "coord_start",
                "type": "int",
            },
            {
                "default": None,
                "description": "Ending chromosome coordinate",
                "name": "coord_end",
                "type": "int",
            },
        ],
    },
    {
        "description": "Given a cCRE (Candidate cis-Regulatory Element), return the "
        "k nearest genes sorted by distance.",
        "name": "get_genes_near_ccre",
        "optional_parameters": [
            {
                "default": 10,
                "description": "Number of nearby genes to return, sorted by distance",
                "name": "k",
                "type": "int",
            }
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "ENCODE Accession ID of query cCRE, e.g., EH38E1516980",
                "name": "accession",
                "type": "str",
            },
            {
                "default": None,
                "description": "Assembly of the gene, e.g., 'GRCh38'",
                "name": "assembly",
                "type": "str",
            },
            {
                "default": None,
                "description": "Chromosome of the gene, e.g., 'chr12'",
                "name": "chromosome",
                "type": "str",
            },
        ],
    },
    {
        "description": "Query the ReMap database for regulatory elements and transcription factor binding sites.",
        "name": "query_remap",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full API endpoint to query (e.g., "
                '"https://remap.univ-amu.fr/api/v1/catalogue/tf?tf=CTCF")',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about transcription factors and binding sites",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the Mouse Phenome Database (MPD) for mouse strain "
        "phenotype data using natural language or direct endpoint "
        "access.",
        "name": "query_mpd",
        "optional_parameters": [
            {
                "default": None,
                "description": "Full API endpoint to query (e.g., 'https://phenomedoc.jax.org/MPD_API/strains')",
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about mouse phenotypes, strains, or measurements",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
    {
        "description": "Query the Electron Microscopy Data Bank (EMDB) for 3D macromolecular structures.",
        "name": "query_emdb",
        "optional_parameters": [
            {
                "default": None,
                "description": 'Full API endpoint to query (e.g., "https://www.ebi.ac.uk/emdb/api/search")',
                "name": "endpoint",
                "type": "str",
            },
            {
                "default": None,
                "description": "Anthropic API key. If None, will use ANTHROPIC_API_KEY env variable",
                "name": "api_key",
                "type": "str",
            },
            {
                "default": "claude-3-5-haiku-20241022",
                "description": "Anthropic model to use for natural language processing",
                "name": "model",
                "type": "str",
            },
            {
                "default": True,
                "description": "Whether to return detailed results",
                "name": "verbose",
                "type": "bool",
            },
        ],
        "required_parameters": [
            {
                "default": None,
                "description": "Natural language query about EM structures and associated data",
                "name": "prompt",
                "type": "str",
            }
        ],
    },
]
